@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 #   Copyright 2017 ProjectQ-Framework (www.projectq.ch)
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
@@ -11,7 +12,6 @@
 #   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 #   See the License for the specific language governing permissions and
 #   limitations under the License.
-
 """
 Contains back-ends for ProjectQ.
 
@@ -25,6 +25,8 @@ This includes:
   circuit)
 * an interface to the IBM Quantum Experience chip (and simulator).
 * an interface to the AQT trapped ion system (and simulator).
+* an interface to the AWS Braket service decives (and simulators)
+* an interface to the IonQ trapped ionq hardware (and simulator).
 """
 from ._printer import CommandPrinter
 from ._circuits import CircuitDrawer, CircuitDrawerMatplotlib
@@ -32,3 +34,5 @@ from ._sim import Simulator, ClassicalSimulator
 from ._resource import ResourceCounter
 from ._ibm import IBMBackend
 from ._aqt import AQTBackend
+from ._awsbraket import AWSBraketBackend
+from ._ionq import IonQBackend
