@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 #   Copyright 2018 ProjectQ-Framework (www.projectq.ch)
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
@@ -11,7 +12,6 @@
 #   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 #   See the License for the specific language governing permissions and
 #   limitations under the License.
-
 """Tests for projectq.cengines._2dmapper.py."""
 
 from copy import deepcopy
@@ -23,8 +23,7 @@ import pytest
 import projectq
 from projectq.cengines import DummyEngine, LocalOptimizer
 from projectq.meta import LogicalQubitIDTag
-from projectq.ops import (Allocate, BasicGate, Command, Deallocate, FlushGate,
-                          X)
+from projectq.ops import Allocate, BasicGate, Command, Deallocate, FlushGate, X
 from projectq.types import WeakQubitRef
 
 from projectq.cengines import _twodmapper as two_d
@@ -48,12 +47,10 @@ def test_is_available():
 def test_wrong_init_mapped_ids_to_backend_ids():
     with pytest.raises(RuntimeError):
         test = {0: 1, 1: 0, 2: 2, 3: 3, 4: 4}
-        two_d.GridMapper(num_rows=2, num_columns=3,
-                         mapped_ids_to_backend_ids=test)
+        two_d.GridMapper(num_rows=2, num_columns=3, mapped_ids_to_backend_ids=test)
     with pytest.raises(RuntimeError):
         test = {0: 1, 1: 0, 2: 2, 3: 3, 4: 4, 5: 2}
-        two_d.GridMapper(num_rows=2, num_columns=3,
-                         mapped_ids_to_backend_ids=test)
+        two_d.GridMapper(num_rows=2, num_columns=3, mapped_ids_to_backend_ids=test)
 
 
 def test_resetting_mapping_to_none():
@@ -67,12 +64,23 @@ def test_resetting_mapping_to_none():
 @pytest.mark.parametrize("different_backend_ids", [False, True])
 def test_return_new_mapping(different_backend_ids):
     if different_backend_ids:
-        map_to_backend_ids = {0: 21, 1: 32, 2: 1, 3: 4, 4: 5, 5: 6, 6: 10,
-                              7: 7, 8: 0, 9: 56, 10: 55, 11: 9}
+        map_to_backend_ids = {
+            0: 21,
+            1: 32,
+            2: 1,
+            3: 4,
+            4: 5,
+            5: 6,
+            6: 10,
+            7: 7,
+            8: 0,
+            9: 56,
+            10: 55,
+            11: 9,
+        }
     else:
         map_to_backend_ids = None
-    mapper = two_d.GridMapper(num_rows=4, num_columns=3,
-                              mapped_ids_to_backend_ids=map_to_backend_ids)
+    mapper = two_d.GridMapper(num_rows=4, num_columns=3, mapped_ids_to_backend_ids=map_to_backend_ids)
     eng = projectq.MainEngine(DummyEngine(), [mapper])
     linear_chain_ids = [33, 22, 11, 2, 3, 0, 6, 7, 9, 12, 4, 88]
     mapper._stored_commands = []
@@ -82,16 +90,39 @@ def test_return_new_mapping(different_backend_ids):
         mapper._stored_commands.append(cmd)
     for i in range(11):
         qb0 = WeakQubitRef(engine=None, idx=linear_chain_ids[i])
-        qb1 = WeakQubitRef(engine=None, idx=linear_chain_ids[i+1])
+        qb1 = WeakQubitRef(engine=None, idx=linear_chain_ids[i + 1])
         cmd = Command(None, X, qubits=([qb0],), controls=[qb1])
         mapper._stored_commands.append(cmd)
     new_mapping = mapper._return_new_mapping()
-    possible_solution_1 = {33: 0, 22: 1, 11: 2, 2: 5, 3: 4, 0: 3, 6: 6, 7: 7,
-                           9: 8, 12: 11, 4: 10, 88: 9}
-    possible_solution_2 = {88: 0, 4: 1, 12: 2, 9: 5, 7: 4, 6: 3, 0: 6, 3: 7,
-                           2: 8, 11: 11, 22: 10, 33: 9}
-    assert (new_mapping == possible_solution_1 or
-            new_mapping == possible_solution_2)
+    possible_solution_1 = {
+        33: 0,
+        22: 1,
+        11: 2,
+        2: 5,
+        3: 4,
+        0: 3,
+        6: 6,
+        7: 7,
+        9: 8,
+        12: 11,
+        4: 10,
+        88: 9,
+    }
+    possible_solution_2 = {
+        88: 0,
+        4: 1,
+        12: 2,
+        9: 5,
+        7: 4,
+        6: 3,
+        0: 6,
+        3: 7,
+        2: 8,
+        11: 11,
+        22: 10,
+        33: 9,
+    }
+    assert new_mapping == possible_solution_1 or new_mapping == possible_solution_2
     eng.flush()
     if different_backend_ids:
         transformed_sol1 = dict()
@@ -100,17 +131,23 @@ def test_return_new_mapping(different_backend_ids):
         transformed_sol2 = dict()
         for logical_id, mapped_id in possible_solution_2.items():
             transformed_sol2[logical_id] = map_to_backend_ids[mapped_id]
-        assert (mapper.current_mapping == transformed_sol1 or
-                mapper.current_mapping == transformed_sol2)
+        assert mapper.current_mapping == transformed_sol1 or mapper.current_mapping == transformed_sol2
     else:
-        assert (mapper.current_mapping == possible_solution_1 or
-                mapper.current_mapping == possible_solution_2)
+        assert mapper.current_mapping == possible_solution_1 or mapper.current_mapping == possible_solution_2
 
 
-@pytest.mark.parametrize("num_rows, num_columns, seed, none_old, none_new",
-                         [(2, 2, 0, 0, 0), (3, 4, 1, 0, 0), (4, 3, 2, 0, 0),
-                          (5, 5, 3, 0, 0), (5, 3, 4, 3, 0), (4, 4, 5, 0, 3),
-                          (6, 6, 7, 2, 3)])
+@pytest.mark.parametrize(
+    "num_rows, num_columns, seed, none_old, none_new",
+    [
+        (2, 2, 0, 0, 0),
+        (3, 4, 1, 0, 0),
+        (4, 3, 2, 0, 0),
+        (5, 5, 3, 0, 0),
+        (5, 3, 4, 3, 0),
+        (4, 4, 5, 0, 3),
+        (6, 6, 7, 2, 3),
+    ],
+)
 def test_return_swaps_random(num_rows, num_columns, seed, none_old, none_new):
     random.seed(seed)
     num_qubits = num_rows * num_columns
@@ -131,16 +168,15 @@ def test_return_swaps_random(num_rows, num_columns, seed, none_old, none_new):
         for logical_id in new_none_ids:
             new_mapping.pop(logical_id)
 
-    mapper = two_d.GridMapper(num_rows=num_rows,
-                              num_columns=num_columns)
+    mapper = two_d.GridMapper(num_rows=num_rows, num_columns=num_columns)
     swaps = mapper.return_swaps(old_mapping, new_mapping)
     # Check that Swaps are allowed
     all_allowed_swaps = set()
     for row in range(num_rows):
-        for column in range(num_columns-1):
+        for column in range(num_columns - 1):
             qb_id = row * num_columns + column
             all_allowed_swaps.add((qb_id, qb_id + 1))
-    for row in range(num_rows-1):
+    for row in range(num_rows - 1):
         for column in range(num_columns):
             qb_id = row * num_columns + column
             all_allowed_swaps.add((qb_id, qb_id + num_columns))
@@ -161,24 +197,30 @@ def test_return_swaps_random(num_rows, num_columns, seed, none_old, none_new):
 @pytest.mark.parametrize("different_backend_ids", [False, True])
 def test_send_possible_commands(different_backend_ids):
     if different_backend_ids:
-        map_to_backend_ids = {0: 21, 1: 32, 2: 1, 3: 4, 4: 5, 5: 6, 6: 10,
-                              7: 7}
+        map_to_backend_ids = {0: 21, 1: 32, 2: 1, 3: 4, 4: 5, 5: 6, 6: 10, 7: 7}
     else:
         map_to_backend_ids = None
-    mapper = two_d.GridMapper(num_rows=2, num_columns=4,
-                              mapped_ids_to_backend_ids=map_to_backend_ids)
+    mapper = two_d.GridMapper(num_rows=2, num_columns=4, mapped_ids_to_backend_ids=map_to_backend_ids)
     backend = DummyEngine(save_commands=True)
     backend.is_last_engine = True
     mapper.next_engine = backend
     # mapping is identical except 5 <-> 0
     if different_backend_ids:
-        mapper.current_mapping = {0: 6, 1: 32, 2: 1, 3: 4, 4: 5, 5: 21, 6: 10,
-                                  7: 7}
+        mapper.current_mapping = {0: 6, 1: 32, 2: 1, 3: 4, 4: 5, 5: 21, 6: 10, 7: 7}
     else:
-        mapper.current_mapping = {5: 0, 1: 1, 2: 2, 3: 3, 4: 4, 0: 5, 6: 6,
-                                  7: 7}
-    neighbours = [(5, 1), (1, 2), (2, 3), (4, 0), (0, 6), (6, 7),
-                  (5, 4), (1, 0), (2, 6), (3, 7)]
+        mapper.current_mapping = {5: 0, 1: 1, 2: 2, 3: 3, 4: 4, 0: 5, 6: 6, 7: 7}
+    neighbours = [
+        (5, 1),
+        (1, 2),
+        (2, 3),
+        (4, 0),
+        (0, 6),
+        (6, 7),
+        (5, 4),
+        (1, 0),
+        (2, 6),
+        (3, 7),
+    ]
     for qb0_id, qb1_id in neighbours:
         qb0 = WeakQubitRef(engine=None, idx=qb0_id)
         qb1 = WeakQubitRef(engine=None, idx=qb1_id)
@@ -188,8 +230,7 @@ def test_send_possible_commands(different_backend_ids):
         mapper._send_possible_commands()
         assert len(mapper._stored_commands) == 0
     for qb0_id, qb1_id in itertools.permutations(range(8), 2):
-        if ((qb0_id, qb1_id) not in neighbours and
-                (qb1_id, qb0_id) not in neighbours):
+        if (qb0_id, qb1_id) not in neighbours and (qb1_id, qb0_id) not in neighbours:
             qb0 = WeakQubitRef(engine=None, idx=qb0_id)
             qb1 = WeakQubitRef(engine=None, idx=qb1_id)
             cmd = Command(None, X, qubits=([qb0],), controls=[qb1])
@@ -204,14 +245,12 @@ def test_send_possible_commands_allocate(different_backend_ids):
         map_to_backend_ids = {0: 21, 1: 32, 2: 3, 3: 4, 4: 5, 5: 6}
     else:
         map_to_backend_ids = None
-    mapper = two_d.GridMapper(num_rows=3, num_columns=2,
-                              mapped_ids_to_backend_ids=map_to_backend_ids)
+    mapper = two_d.GridMapper(num_rows=3, num_columns=2, mapped_ids_to_backend_ids=map_to_backend_ids)
     backend = DummyEngine(save_commands=True)
     backend.is_last_engine = True
     mapper.next_engine = backend
     qb0 = WeakQubitRef(engine=None, idx=0)
-    cmd0 = Command(engine=None, gate=Allocate, qubits=([qb0],), controls=[],
-                   tags=[])
+    cmd0 = Command(engine=None, gate=Allocate, qubits=([qb0],), controls=[], tags=[])
     mapper._stored_commands = [cmd0]
     mapper._currently_allocated_ids = set([10])
     # not in mapping:
@@ -226,8 +265,13 @@ def test_send_possible_commands_allocate(different_backend_ids):
     assert len(mapper._stored_commands) == 0
     # Only self._run() sends Allocate gates
     mapped0 = WeakQubitRef(engine=None, idx=3)
-    received_cmd = Command(engine=mapper, gate=Allocate, qubits=([mapped0],),
-                           controls=[], tags=[LogicalQubitIDTag(0)])
+    received_cmd = Command(
+        engine=mapper,
+        gate=Allocate,
+        qubits=([mapped0],),
+        controls=[],
+        tags=[LogicalQubitIDTag(0)],
+    )
     assert backend.received_commands[0] == received_cmd
     assert mapper._currently_allocated_ids == set([10, 0])
 
@@ -238,14 +282,12 @@ def test_send_possible_commands_deallocate(different_backend_ids):
         map_to_backend_ids = {0: 21, 1: 32, 2: 3, 3: 4, 4: 5, 5: 6}
     else:
         map_to_backend_ids = None
-    mapper = two_d.GridMapper(num_rows=3, num_columns=2,
-                              mapped_ids_to_backend_ids=map_to_backend_ids)
+    mapper = two_d.GridMapper(num_rows=3, num_columns=2, mapped_ids_to_backend_ids=map_to_backend_ids)
     backend = DummyEngine(save_commands=True)
     backend.is_last_engine = True
     mapper.next_engine = backend
     qb0 = WeakQubitRef(engine=None, idx=0)
-    cmd0 = Command(engine=None, gate=Deallocate, qubits=([qb0],), controls=[],
-                   tags=[])
+    cmd0 = Command(engine=None, gate=Deallocate, qubits=([qb0],), controls=[], tags=[])
     mapper._stored_commands = [cmd0]
     mapper.current_mapping = dict()
     mapper._currently_allocated_ids = set([10])
@@ -269,19 +311,15 @@ def test_send_possible_commands_keep_remaining_gates(different_backend_ids):
         map_to_backend_ids = {0: 21, 1: 32, 2: 3, 3: 0, 4: 5, 5: 6}
     else:
         map_to_backend_ids = None
-    mapper = two_d.GridMapper(num_rows=3, num_columns=2,
-                              mapped_ids_to_backend_ids=map_to_backend_ids)
+    mapper = two_d.GridMapper(num_rows=3, num_columns=2, mapped_ids_to_backend_ids=map_to_backend_ids)
     backend = DummyEngine(save_commands=True)
     backend.is_last_engine = True
     mapper.next_engine = backend
     qb0 = WeakQubitRef(engine=None, idx=0)
     qb1 = WeakQubitRef(engine=None, idx=1)
-    cmd0 = Command(engine=None, gate=Allocate, qubits=([qb0],), controls=[],
-                   tags=[])
-    cmd1 = Command(engine=None, gate=Deallocate, qubits=([qb0],), controls=[],
-                   tags=[])
-    cmd2 = Command(engine=None, gate=Allocate, qubits=([qb1],), controls=[],
-                   tags=[])
+    cmd0 = Command(engine=None, gate=Allocate, qubits=([qb0],), controls=[], tags=[])
+    cmd1 = Command(engine=None, gate=Deallocate, qubits=([qb0],), controls=[], tags=[])
+    cmd2 = Command(engine=None, gate=Allocate, qubits=([qb1],), controls=[], tags=[])
 
     mapper._stored_commands = [cmd0, cmd1, cmd2]
     mapper.current_mapping = {0: 0}
@@ -295,15 +333,13 @@ def test_send_possible_commands_one_inactive_qubit(different_backend_ids):
         map_to_backend_ids = {0: 21, 1: 32, 2: 3, 3: 0, 4: 5, 5: 6}
     else:
         map_to_backend_ids = None
-    mapper = two_d.GridMapper(num_rows=3, num_columns=2,
-                              mapped_ids_to_backend_ids=map_to_backend_ids)
+    mapper = two_d.GridMapper(num_rows=3, num_columns=2, mapped_ids_to_backend_ids=map_to_backend_ids)
     backend = DummyEngine(save_commands=True)
     backend.is_last_engine = True
     mapper.next_engine = backend
     qb0 = WeakQubitRef(engine=None, idx=0)
     qb1 = WeakQubitRef(engine=None, idx=1)
-    cmd0 = Command(engine=None, gate=Allocate, qubits=([qb0],), controls=[],
-                   tags=[])
+    cmd0 = Command(engine=None, gate=Allocate, qubits=([qb0],), controls=[], tags=[])
     cmd1 = Command(engine=None, gate=X, qubits=([qb0],), controls=[qb1])
     mapper._stored_commands = [cmd0, cmd1]
     mapper.current_mapping = {0: 0}
@@ -329,7 +365,8 @@ def test_run_and_receive(num_optimization_steps, different_backend_ids):
         num_columns=2,
         mapped_ids_to_backend_ids=map_to_backend_ids,
         optimization_function=choose_last_permutation,
-        num_optimization_steps=num_optimization_steps)
+        num_optimization_steps=num_optimization_steps,
+    )
     backend = DummyEngine(save_commands=True)
     backend.is_last_engine = True
     mapper.next_engine = backend
@@ -356,15 +393,19 @@ def test_run_and_receive(num_optimization_steps, different_backend_ids):
     assert len(backend.received_commands) == 10
     assert mapper._currently_allocated_ids == set([0, 2, 3])
     if different_backend_ids:
-        assert (mapper.current_mapping == {0: 21, 2: 3, 3: 0} or
-                mapper.current_mapping == {0: 32, 2: 0, 3: 21} or
-                mapper.current_mapping == {0: 3, 2: 21, 3: 32} or
-                mapper.current_mapping == {0: 0, 2: 32, 3: 3})
+        assert (
+            mapper.current_mapping == {0: 21, 2: 3, 3: 0}
+            or mapper.current_mapping == {0: 32, 2: 0, 3: 21}
+            or mapper.current_mapping == {0: 3, 2: 21, 3: 32}
+            or mapper.current_mapping == {0: 0, 2: 32, 3: 3}
+        )
     else:
-        assert (mapper.current_mapping == {0: 0, 2: 2, 3: 3} or
-                mapper.current_mapping == {0: 1, 2: 3, 3: 0} or
-                mapper.current_mapping == {0: 2, 2: 0, 3: 1} or
-                mapper.current_mapping == {0: 3, 2: 1, 3: 2})
+        assert (
+            mapper.current_mapping == {0: 0, 2: 2, 3: 3}
+            or mapper.current_mapping == {0: 1, 2: 3, 3: 0}
+            or mapper.current_mapping == {0: 2, 2: 0, 3: 1}
+            or mapper.current_mapping == {0: 3, 2: 1, 3: 2}
+        )
     cmd9 = Command(None, X, qubits=([qb0],), controls=[qb3])
     mapper.storage = 1
     mapper.receive([cmd9])
@@ -419,8 +460,7 @@ def test_correct_stats():
     cmd8 = Command(None, X, qubits=([qb1],), controls=[qb2])
     qb_flush = WeakQubitRef(engine=None, idx=-1)
     cmd_flush = Command(engine=None, gate=FlushGate(), qubits=([qb_flush],))
-    mapper.receive([cmd0, cmd1, cmd2, cmd3, cmd4, cmd5, cmd6, cmd7, cmd8,
-                    cmd_flush])
+    mapper.receive([cmd0, cmd1, cmd2, cmd3, cmd4, cmd5, cmd6, cmd7, cmd8, cmd_flush])
     assert mapper.num_mappings == 2
 
 
@@ -430,7 +470,8 @@ def test_send_possible_cmds_before_new_mapping():
     backend.is_last_engine = True
     mapper.next_engine = backend
 
-    def dont_call_mapping(): raise Exception
+    def dont_call_mapping():
+        raise Exception
 
     mapper._return_new_mapping = dont_call_mapping
     mapper.current_mapping = {0: 1}
